//[mahjong-utils](../../../index.md)/[mahjongutils](../index.md)/[ValidationException](index.md)/[message](message.md)

# message

[common]\
open override val [message](message.md): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)
